<h1 align="center">findit</h1>
<p align="center">
    <em>Find target icon on your picture, and get its position.</em>
</p>

---

[![Python 3.6](https://img.shields.io/badge/python-3.6+-blue.svg)](https://www.python.org/downloads/release/python-360/)
[![PyPI version](https://badge.fury.io/py/findit.svg)](https://badge.fury.io/py/findit)
![Travis (.org)](https://img.shields.io/travis/williamfzc/findit.svg?label=Travis%20CI)
![Docker Cloud Build Status](https://img.shields.io/docker/cloud/build/williamfzc/findit.svg)
[![Maintainability](https://api.codeclimate.com/v1/badges/d824d06146383ef721c8/maintainability)](https://codeclimate.com/github/williamfzc/findit/maintainability)

---

# 定位

![feature_matching](docs/pics/feature_matching_sample.png)

findit 极大简化了图像识别的繁琐流程，强大而简洁的API让你只需要几行代码就可以在你的目标图片中找到模板图片的位置！

目前，[stagesep2](https://github.com/williamfzc/stagesep2) 与 [fitch](https://github.com/williamfzc/fitch) 均使用该工具作为图像处理引擎。

# 快速开始

 从我们的 [官方文档](https://williamfzc.github.io/findit/) 开始吧！

# LICENSE

[MIT](LICENSE)
